==> grafana-alloy-debug-1.11.3-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.44.0/api/datadogV2/model_gcp_usage_cost_configs_response.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// GCPUsageCostConfigsResponse List of GCP Usage Cost configs.
type GCPUsageCostConfigsResponse struct {
	// A GCP Usage Cost config.
	Data []GCPUsageCostConfig `json:"data,omitempty"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewGCPUsageCostConfigsResponse instantiates a new GCPUsageCostConfigsResponse object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewGCPUsageCostConfigsResponse() *GCPUsageCostConfigsResponse {
	this := GCPUsageCostConfigsResponse{}
	return &this
}

// NewGCPUsageCostConfigsResponseWithDefaults instantiates a new GCPUsageCostConfigsResponse object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewGCPUsageCostConfigsResponseWithDefaults() *GCPUsageCostConfigsResponse {
	this := GCPUsageCostConfigsResponse{}
	return &this
}

// GetData returns the Data field value if set, zero value otherwise.
func (o *GCPUsageCostConfigsResponse) GetData() []GCPUsageCostConfig {
	if o == nil || o.Data == nil {
		var ret []GCPUsageCostConfig
		return ret
	}
	return o.Data
}

// GetDataOk returns a tuple with the Data field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *GCPUsageCostConfigsResponse) GetDataOk() (*[]GCPUsageCostConfig, bool) {
	if o == nil || o.Data == nil {
		return nil, false
	}
	return &o.Data, true
}

// HasData returns a boolean if a field has been set.
func (o *GCPUsageCostConfigsResponse) HasData() bool {
	return o != nil && o.Data != nil
}

// SetData gets a reference to the given []GCPUsageCostConfig and assigns it to the Data field.
func (o *GCPUsageCostConfigsResponse) SetData(v []GCPUsageCostConfig) {
	o.Data = v
}

// MarshalJSON serializes the struct using spec logic.
func (o GCPUsageCostConfigsResponse) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	if o.Data != nil {
		toSerialize["data"] = o.Data
	}

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *GCPUsageCostConfigsResponse) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Data []GCPUsageCostConfig `json:"data,omitempty"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"data"})
	} else {
		return err
	}
	o.Data = all.Data

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	return nil
}

==> grafana-alloy-debug-1.12.2-3-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.48.0/api/datadogV2/model_gcp_usage_cost_configs_response.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"fmt"

	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// GCPUsageCostConfigsResponse List of Google Cloud Usage Cost configs.
type GCPUsageCostConfigsResponse struct {
	// A Google Cloud Usage Cost config.
	Data []GCPUsageCostConfig `json:"data"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewGCPUsageCostConfigsResponse instantiates a new GCPUsageCostConfigsResponse object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewGCPUsageCostConfigsResponse(data []GCPUsageCostConfig) *GCPUsageCostConfigsResponse {
	this := GCPUsageCostConfigsResponse{}
	this.Data = data
	return &this
}

// NewGCPUsageCostConfigsResponseWithDefaults instantiates a new GCPUsageCostConfigsResponse object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewGCPUsageCostConfigsResponseWithDefaults() *GCPUsageCostConfigsResponse {
	this := GCPUsageCostConfigsResponse{}
	return &this
}

// GetData returns the Data field value.
func (o *GCPUsageCostConfigsResponse) GetData() []GCPUsageCostConfig {
	if o == nil {
		var ret []GCPUsageCostConfig
		return ret
	}
	return o.Data
}

// GetDataOk returns a tuple with the Data field value
// and a boolean to check if the value has been set.
func (o *GCPUsageCostConfigsResponse) GetDataOk() (*[]GCPUsageCostConfig, bool) {
	if o == nil {
		return nil, false
	}
	return &o.Data, true
}

// SetData sets field value.
func (o *GCPUsageCostConfigsResponse) SetData(v []GCPUsageCostConfig) {
	o.Data = v
}

// MarshalJSON serializes the struct using spec logic.
func (o GCPUsageCostConfigsResponse) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	toSerialize["data"] = o.Data

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *GCPUsageCostConfigsResponse) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Data *[]GCPUsageCostConfig `json:"data"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	if all.Data == nil {
		return fmt.Errorf("required field data missing")
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"data"})
	} else {
		return err
	}
	o.Data = *all.Data

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	return nil
}
